import { __decorate } from 'tslib';
import { Injectable, ElementRef, HostBinding, Input, Component, ContentChildren, EventEmitter, Output, NgModule } from '@angular/core';
import { CommonsComponent, NgxAngularCommonsCoreModule } from 'ngx-angularcommons-core';
import { ReplaySubject } from 'rxjs';
import { CommonsType } from 'tscommons-core';
import { CommonModule } from '@angular/common';
import { NgxAngularCommonsBrowserModule } from 'ngx-angularcommons-browser';
import { NgxAngularCommonsPipeModule } from 'ngx-angularcommons-pipe';
import { NgxWebAppCommonsCoreModule } from 'ngx-webappcommons-core';
import { NgxWebAppCommonsFormModule } from 'ngx-webappcommons-form';

let CommonsTable2Service = class CommonsTable2Service {
    constructor() {
        this.onColumnsChanged = new Map();
        this.onSelectable = new Map();
        this.selectable = new Map();
        this.onDisabled = new Map();
        this.disabled = new Map();
    }
    registerTable(component) {
        this.onColumnsChanged.set(component, new ReplaySubject(1));
        this.onSelectable.set(component, new ReplaySubject(1));
        this.selectable.set(component, undefined);
        this.onDisabled.set(component, new ReplaySubject(1));
        this.disabled.set(component, false);
    }
    columnsChangedObservable(component) {
        if (!this.onColumnsChanged.has(component))
            throw new Error('Unregistered table');
        return this.onColumnsChanged.get(component);
    }
    cascadeColumnsChanged(component, columns) {
        if (!this.onColumnsChanged.has(component))
            throw new Error('Unregistered table');
        this.onColumnsChanged.get(component).next(columns);
    }
    selectableObservable(component) {
        if (!this.onSelectable.has(component))
            throw new Error('Unregistered table');
        return this.onSelectable.get(component);
    }
    cascadeSelectable(component, selectable) {
        if (!this.onSelectable.has(component))
            throw new Error('Unregistered table');
        this.selectable.set(component, selectable);
        this.onSelectable.get(component).next(selectable);
    }
    getSelectable(component) {
        if (!this.selectable.has(component))
            throw new Error('Unregistered table');
        return this.selectable.get(component);
    }
    disabledObservable(component) {
        if (!this.onSelectable.has(component))
            throw new Error('Unregistered table');
        return this.onDisabled.get(component);
    }
    cascadeDisabled(component, disabled) {
        if (!this.onDisabled.has(component))
            throw new Error('Unregistered table');
        this.disabled.set(component, disabled);
        this.onDisabled.get(component).next(disabled);
    }
    getDisabled(component) {
        if (!this.disabled.has(component))
            throw new Error('Unregistered table');
        return this.disabled.get(component);
    }
};
CommonsTable2Service = __decorate([
    Injectable()
], CommonsTable2Service);

class CommonsTable2Columns {
    static listColumns(contentChildren) {
        if (!contentChildren)
            return [];
        const columns = contentChildren
            .map((child) => ({
            name: child.name,
            width: child.width
        }));
        return columns;
    }
    static getGridTemplateColumns(columns) {
        const widths = columns
            .map((column) => column.width || '1fr');
        return widths.join(' ');
    }
}

let CommonsTable2HeaderColumnComponent = class CommonsTable2HeaderColumnComponent extends CommonsComponent {
    constructor(ref) {
        super();
        this.ref = ref;
    }
    ngAfterContentInit() {
        if (!this.title)
            this.title = this.ref.nativeElement.innerText;
    }
};
CommonsTable2HeaderColumnComponent.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    HostBinding('title'), Input()
], CommonsTable2HeaderColumnComponent.prototype, "title", void 0);
__decorate([
    Input()
], CommonsTable2HeaderColumnComponent.prototype, "name", void 0);
__decorate([
    Input()
], CommonsTable2HeaderColumnComponent.prototype, "width", void 0);
CommonsTable2HeaderColumnComponent = __decorate([
    Component({
        selector: '[commons-table2-header-column]',
        template: "<ng-content></ng-content>\n",
        styles: [":host{display:block;text-align:left;box-sizing:border-box;padding:0 16px;overflow:hidden;white-space:nowrap;text-overflow:ellipsis;font-family:Roboto;font-weight:500;font-size:14px;line-height:21px}"]
    })
], CommonsTable2HeaderColumnComponent);

let CommonsTable2BodyComponent = class CommonsTable2BodyComponent extends CommonsComponent {
};
CommonsTable2BodyComponent = __decorate([
    Component({
        selector: '[commons-table2-body]',
        template: "<ng-content></ng-content>\n",
        styles: [":host{display:block}"]
    })
], CommonsTable2BodyComponent);

let CommonsTable2Component = class CommonsTable2Component extends CommonsComponent {
    constructor(service) {
        super();
        this.service = service;
        this.disabled = false;
        // these have to be public so that the other component classes can access them
        this.columns = [];
        this.service.registerTable(this);
    }
    ngOnInit() {
        super.ngOnInit();
        this.service.cascadeSelectable(this, this.selectable);
        this.service.cascadeDisabled(this, this.disabled);
    }
    ngOnChanges(changes) {
        if (changes.selectable && changes.selectable.currentValue !== changes.selectable.previousValue) {
            this.service.cascadeSelectable(this, this.selectable);
        }
        if (changes.disabled && changes.disabled.currentValue !== changes.disabled.previousValue) {
            this.service.cascadeDisabled(this, this.disabled);
        }
    }
    ngAfterContentInit() {
        this.subscribe(this.columnsContentChildren.changes, () => {
            this.refreshColumns();
        });
        this.refreshColumns();
    }
    refreshColumns() {
        this.columns = CommonsTable2Columns.listColumns(this.columnsContentChildren);
        this.service.cascadeColumnsChanged(this, this.columns);
    }
};
CommonsTable2Component.ctorParameters = () => [
    { type: CommonsTable2Service }
];
__decorate([
    ContentChildren(CommonsTable2HeaderColumnComponent, { descendants: true })
], CommonsTable2Component.prototype, "columnsContentChildren", void 0);
__decorate([
    ContentChildren(CommonsTable2BodyComponent)
], CommonsTable2Component.prototype, "bodyContentChildren", void 0);
__decorate([
    Input()
], CommonsTable2Component.prototype, "selectable", void 0);
__decorate([
    Input()
], CommonsTable2Component.prototype, "disabled", void 0);
CommonsTable2Component = __decorate([
    Component({
        selector: '[commons-table2]',
        template: "<ng-content></ng-content>\n",
        styles: ["@charset 'utf8';:host{display:block;box-sizing:border-box;width:100%;border:1px solid #000;margin:0;padding:0;border-collapse:collapse;border-spacing:0;border-radius:4px;font-family:Roboto}:host /deep/ tr{border-top-style:solid;border-top-width:1px}:host /deep/ thead>tr:first-child{border-top:none}:host-context(body.webappcommons-theme-blue.theme-light){border-color:#e0e0e0;color:#333}:host-context(body.webappcommons-theme-blue.theme-dark){border-color:#404040;color:#ccc}:host-context(body.webappcommons-theme-blue.theme-light) /deep/ tr{border-top-color:#e0e0e0}:host-context(body.webappcommons-theme-blue.theme-dark) /deep/ tr{border-top-color:#404040}:host-context(body.webappcommons-theme-darkred.theme-light){border-color:#383838;color:#b8b8b8}:host-context(body.webappcommons-theme-darkred.theme-dark){border-color:#afafaf;color:#474747}:host-context(body.webappcommons-theme-darkred.theme-light) /deep/ tr{border-top-color:#383838}:host-context(body.webappcommons-theme-darkred.theme-dark) /deep/ tr{border-top-color:#afafaf}:host-context(body.webappcommons-theme-hotpink.theme-light){border-color:#e0e0e0;color:#333}:host-context(body.webappcommons-theme-hotpink.theme-dark){border-color:#404040;color:#ccc}:host-context(body.webappcommons-theme-hotpink.theme-light) /deep/ tr{border-top-color:#e0e0e0}:host-context(body.webappcommons-theme-hotpink.theme-dark) /deep/ tr{border-top-color:#404040}:host-context(body.webappcommons-theme-marine.theme-light){border-color:#e0e0e0;color:#333}:host-context(body.webappcommons-theme-marine.theme-dark){border-color:#404040;color:#ccc}:host-context(body.webappcommons-theme-marine.theme-light) /deep/ tr{border-top-color:#e0e0e0}:host-context(body.webappcommons-theme-marine.theme-dark) /deep/ tr{border-top-color:#404040}:host-context(body.webappcommons-theme-muted.theme-light){border-color:#e0e0e0;color:#333}:host-context(body.webappcommons-theme-muted.theme-dark){border-color:#404040;color:#ccc}:host-context(body.webappcommons-theme-muted.theme-light) /deep/ tr{border-top-color:#e0e0e0}:host-context(body.webappcommons-theme-muted.theme-dark) /deep/ tr{border-top-color:#404040}:host-context(body.webappcommons-theme-night.theme-light){border-color:#e0e0e0;color:#333}:host-context(body.webappcommons-theme-night.theme-dark){border-color:#404040;color:#ccc}:host-context(body.webappcommons-theme-night.theme-light) /deep/ tr{border-top-color:#e0e0e0}:host-context(body.webappcommons-theme-night.theme-dark) /deep/ tr{border-top-color:#404040}:host-context(body.webappcommons-theme-patrolred.theme-light){border-color:#e0e0e0;color:#333}:host-context(body.webappcommons-theme-patrolred.theme-dark){border-color:#404040;color:#ccc}:host-context(body.webappcommons-theme-patrolred.theme-light) /deep/ tr{border-top-color:#e0e0e0}:host-context(body.webappcommons-theme-patrolred.theme-dark) /deep/ tr{border-top-color:#404040}:host-context(body.webappcommons-theme-purple.theme-light){border-color:#e0e0e0;color:#333}:host-context(body.webappcommons-theme-purple.theme-dark){border-color:#404040;color:#ccc}:host-context(body.webappcommons-theme-purple.theme-light) /deep/ tr{border-top-color:#e0e0e0}:host-context(body.webappcommons-theme-purple.theme-dark) /deep/ tr{border-top-color:#404040}"]
    })
], CommonsTable2Component);

let CommonsTable2BodyCellComponent = class CommonsTable2BodyCellComponent extends CommonsComponent {
};
CommonsTable2BodyCellComponent = __decorate([
    Component({
        selector: '[commons-table2-body-cell]',
        template: "<ng-content></ng-content>\n",
        styles: [":host{display:block;text-align:left;box-sizing:border-box;padding:0 16px;overflow:hidden;white-space:nowrap;text-overflow:ellipsis;font-family:Roboto;font-weight:400;font-size:14px;line-height:21px}"]
    })
], CommonsTable2BodyCellComponent);

let CommonsTable2BodyRowComponent = class CommonsTable2BodyRowComponent extends CommonsComponent {
    constructor(root, service) {
        super();
        this.root = root;
        this.service = service;
        this.selectedChange = new EventEmitter(true);
        this.disabled = false;
    }
    ngOnInit() {
        super.ngOnInit();
        this.subscribe(this.service.selectableObservable(this.root), (selectable) => {
            setTimeout(() => { this.selectable = selectable; }, 0);
        });
        this.selectable = this.service.getSelectable(this.root);
        this.subscribe(this.service.disabledObservable(this.root), (disabled) => {
            setTimeout(() => { this.disabled = disabled; }, 0);
        });
        this.disabled = this.service.getDisabled(this.root);
        this.subscribe(this.service.columnsChangedObservable(this.root), (columns) => {
            let widths = CommonsTable2Columns.getGridTemplateColumns(columns);
            if (this.selectable !== undefined)
                widths = `52px ${widths}`;
            setTimeout(() => { this.hostGridTemplateColumns = widths; }, 0);
        });
    }
    doSelected() {
        this.selectedChange.emit(this.selected);
    }
};
CommonsTable2BodyRowComponent.ctorParameters = () => [
    { type: CommonsTable2Component },
    { type: CommonsTable2Service }
];
__decorate([
    HostBinding('style.gridTemplateColumns')
], CommonsTable2BodyRowComponent.prototype, "hostGridTemplateColumns", void 0);
__decorate([
    HostBinding('class.selected'), Input()
], CommonsTable2BodyRowComponent.prototype, "selected", void 0);
__decorate([
    Output()
], CommonsTable2BodyRowComponent.prototype, "selectedChange", void 0);
CommonsTable2BodyRowComponent = __decorate([
    Component({
        selector: '[commons-table2-body-row]',
        template: "<td *ngIf=\"this.selectable !== undefined\">\n\t<commons-checkbox\n\t\t\t[disabled]=\"this.disabled\"\n\t\t\t[(checked)]=\"this.selected\"\n\t\t\t(checkedChange)=\"this.doSelected();\"\n\t></commons-checkbox>\n</td>\n<ng-content></ng-content>\n",
        styles: ["@charset 'utf8';:host{display:grid;box-sizing:content-box;padding:6px 0;grid-auto-columns:auto;grid-template-rows:40px;align-items:center}:host-context(body.webappcommons-theme-blue):hover{background-color:#f2f2f2}:host-context(body.webappcommons-theme-blue).selected{background-color:rgba(122,124,255,.1)}:host-context(body.webappcommons-theme-darkred):hover{background-color:#2a2a2a}:host-context(body.webappcommons-theme-darkred).selected{background-color:rgba(255,81,49,.1)}:host-context(body.webappcommons-theme-hotpink):hover{background-color:#f2f2f2}:host-context(body.webappcommons-theme-hotpink).selected{background-color:rgba(255,156,229,.1)}:host-context(body.webappcommons-theme-marine):hover{background-color:#f2f2f2}:host-context(body.webappcommons-theme-marine).selected{background-color:rgba(101,197,224,.1)}:host-context(body.webappcommons-theme-muted):hover{background-color:#f2f2f2}:host-context(body.webappcommons-theme-muted).selected{background-color:rgba(129,156,169,.1)}:host-context(body.webappcommons-theme-night):hover{background-color:#f2f2f2}:host-context(body.webappcommons-theme-night).selected{background-color:rgba(143,173,197,.1)}:host-context(body.webappcommons-theme-patrolred):hover{background-color:#f2f2f2}:host-context(body.webappcommons-theme-patrolred).selected{background-color:rgba(255,81,70,.1)}:host-context(body.webappcommons-theme-purple):hover{background-color:#f2f2f2}:host-context(body.webappcommons-theme-purple).selected{background-color:rgba(191,115,230,.1)}td{display:block;box-sizing:border-box;padding:0 16px}td commons-checkbox{position:relative;top:2px}"]
    })
], CommonsTable2BodyRowComponent);

let CommonsTable2FooterComponent = class CommonsTable2FooterComponent extends CommonsComponent {
};
CommonsTable2FooterComponent = __decorate([
    Component({
        selector: '[commons-table2-footer]',
        template: "<ng-content></ng-content>\n",
        styles: [":host{display:block}"]
    })
], CommonsTable2FooterComponent);

let CommonsTable2FooterPaginationComponent = class CommonsTable2FooterPaginationComponent extends CommonsComponent {
    constructor() {
        super(...arguments);
        this.rowsChange = new EventEmitter(true);
        this.onFirst = new EventEmitter(true);
        this.onBack = new EventEmitter(true);
        this.onForward = new EventEmitter(true);
        this.onLast = new EventEmitter(true);
    }
    doChangeRows() {
        this.rowsChange.emit(parseInt(this.internalRows, 10));
    }
    ngOnChanges(_changes) {
        this.internalRows = this.rows === undefined ? undefined : this.rows.toString();
        const thisPageEnd = (this.from || 0) + (this.rows || 0);
        this.canBack = this.rows !== undefined
            && this.from !== undefined
            && this.total
            && this.from > 0;
        this.canForward = this.rows !== undefined
            && this.total
            && thisPageEnd < this.total;
    }
};
__decorate([
    Input()
], CommonsTable2FooterPaginationComponent.prototype, "from", void 0);
__decorate([
    Input()
], CommonsTable2FooterPaginationComponent.prototype, "total", void 0);
__decorate([
    Input()
], CommonsTable2FooterPaginationComponent.prototype, "rows", void 0);
__decorate([
    Output()
], CommonsTable2FooterPaginationComponent.prototype, "rowsChange", void 0);
__decorate([
    Output()
], CommonsTable2FooterPaginationComponent.prototype, "onFirst", void 0);
__decorate([
    Output()
], CommonsTable2FooterPaginationComponent.prototype, "onBack", void 0);
__decorate([
    Output()
], CommonsTable2FooterPaginationComponent.prototype, "onForward", void 0);
__decorate([
    Output()
], CommonsTable2FooterPaginationComponent.prototype, "onLast", void 0);
CommonsTable2FooterPaginationComponent = __decorate([
    Component({
        selector: '[commons-table2-footer-pagination]',
        template: "<section container>\n\t<span filler></span>\n\t\n\t<span rows>\n\t\t<label for=\"rows\">Rows per page</label>\n\t\t<commons-textbox class=\"compact inline\"\n\t\t\t\t[options]=\"[ '5', '10', '15', '20' ]\"\n\t\t\t\t[optionsOnly]=\"true\"\n\t\t\t\t[clearable]=\"false\"\n\t\t\t\t[(value)]=\"this.internalRows\"\n\t\t\t\t(valueChange)=\"this.doChangeRows();\"\n\t\t></commons-textbox>\n\t</span>\n\t<span pagination>\n\t\t<ng-container *ngIf=\"this.from !== undefined && this.total !== undefined\">\n\t\t\t{{ this.from + 1 }}&ndash;{{ (this.from + this.rows) >= this.total ? this.total : (this.from + this.rows) }} of {{ this.total }}\n\t\t</ng-container>\n\t</span>\n\t<i class=\"material-icons first\"\n\t\t\t[class.disabled]=\"!this.canBack\"\n\t\t\t(click)=\"this.onFirst.emit();\"\n\t>first_page</i>\n\t<i class=\"material-icons\"\n\t\t\t[class.disabled]=\"!this.canBack\"\n\t\t\t(click)=\"this.onBack.emit();\"\n\t>chevron_left</i>\n\t<i class=\"material-icons\"\n\t\t\t[class.disabled]=\"!this.canForward\"\n\t\t\t(click)=\"this.onForward.emit();\"\n\t>chevron_right</i>\n\t<i class=\"material-icons\"\n\t\t\t[class.disabled]=\"!this.canForward\"\n\t\t\t(click)=\"this.onLast.emit();\"\n\t>last_page</i>\n</section>\n",
        styles: ["@charset 'utf8';:host{display:block;font-family:Roboto;font-weight:400;font-size:14px;line-height:14px}section[container]{width:100%;box-sizing:content-box;padding:6px 0;display:grid;grid-template-columns:1fr auto auto auto auto auto auto;grid-template-rows:40px;align-items:center}section[container] span[rows]{display:grid;grid-template-columns:auto 100px;grid-template-rows:1fr;grid-column-gap:8px;align-items:center;padding:6px 16px;box-sizing:border-box}section[container] span[rows] commons-textbox{position:relative;top:3px}section[container] span[pagination]{display:block;box-sizing:border-box;padding:0 16px}i.material-icons{box-sizing:border-box;padding:0 16px;cursor:pointer}@media only screen and (max-width:619px){section[container]{grid-template-columns:1fr auto auto auto auto auto}section[container] span[pagination]{display:none}i.material-icons{padding-left:0}i.material-icons.first{padding-left:16px}}@media only screen and (max-width:419px){section[container] span[rows]{grid-template-columns:100px}section[container] span[rows] label{display:none}i.material-icons.first{padding-left:0}}:host-context(body.webappcommons-theme-blue) i.material-icons.disabled{color:#c2c2c2;cursor:initial}:host-context(body.webappcommons-theme-darkred) i.material-icons.disabled{color:#4e4e4e;cursor:initial}:host-context(body.webappcommons-theme-hotpink) i.material-icons.disabled{color:#c2c2c2;cursor:initial}:host-context(body.webappcommons-theme-marine) i.material-icons.disabled{color:#c2c2c2;cursor:initial}:host-context(body.webappcommons-theme-muted) i.material-icons.disabled{color:#c2c2c2;cursor:initial}:host-context(body.webappcommons-theme-night) i.material-icons.disabled{color:#c2c2c2;cursor:initial}:host-context(body.webappcommons-theme-patrolred) i.material-icons.disabled{color:#c2c2c2;cursor:initial}:host-context(body.webappcommons-theme-purple) i.material-icons.disabled{color:#c2c2c2;cursor:initial}"]
    })
], CommonsTable2FooterPaginationComponent);

let CommonsTable2HeaderComponent = class CommonsTable2HeaderComponent extends CommonsComponent {
};
CommonsTable2HeaderComponent = __decorate([
    Component({
        selector: '[commons-table2-header]',
        template: "<ng-content></ng-content>\n",
        styles: [":host{display:block}"]
    })
], CommonsTable2HeaderComponent);

var ECommonsTable2Selectable;
(function (ECommonsTable2Selectable) {
    ECommonsTable2Selectable["SINGLE"] = "single";
    ECommonsTable2Selectable["MULTIPLE"] = "multiple";
})(ECommonsTable2Selectable || (ECommonsTable2Selectable = {}));
function toECommonsTable2Selectable(type) {
    switch (type) {
        case ECommonsTable2Selectable.SINGLE.toString():
            return ECommonsTable2Selectable.SINGLE;
        case ECommonsTable2Selectable.MULTIPLE.toString():
            return ECommonsTable2Selectable.MULTIPLE;
    }
    return undefined;
}
function fromECommonsTable2Selectable(type) {
    switch (type) {
        case ECommonsTable2Selectable.SINGLE:
            return ECommonsTable2Selectable.SINGLE.toString();
        case ECommonsTable2Selectable.MULTIPLE:
            return ECommonsTable2Selectable.MULTIPLE.toString();
    }
    throw new Error('Unknown ECommonsTable2Selectable');
}
function isECommonsTable2Selectable(test) {
    if (!CommonsType.isString(test))
        return false;
    return toECommonsTable2Selectable(test) !== undefined;
}
function keyToECommonsTable2Selectable(key) {
    switch (key) {
        case 'SINGLE':
            return ECommonsTable2Selectable.SINGLE;
        case 'MULTIPLE':
            return ECommonsTable2Selectable.MULTIPLE;
    }
    throw new Error(`Unable to obtain ECommonsTable2Selectable for key: ${key}`);
}
const ɵ0 = (e) => keyToECommonsTable2Selectable(e);
const ECOMMONS_TABLE2_SELECTABLES = Object.keys(ECommonsTable2Selectable)
    .map(ɵ0);

let CommonsTable2HeaderColumnsComponent = class CommonsTable2HeaderColumnsComponent extends CommonsComponent {
    constructor(root, service) {
        super();
        this.root = root;
        this.service = service;
        this.ECommonsTable2Selectable = ECommonsTable2Selectable;
        this.selectAll = false;
        this.selectAllChange = new EventEmitter(true);
        this.disabled = false;
    }
    ngOnInit() {
        super.ngOnInit();
        this.subscribe(this.service.selectableObservable(this.root), (selectable) => {
            setTimeout(() => { this.selectable = selectable; }, 0);
        });
        this.selectable = this.service.getSelectable(this.root);
        this.subscribe(this.service.disabledObservable(this.root), (disabled) => {
            setTimeout(() => { this.disabled = disabled; }, 0);
        });
        this.disabled = this.service.getDisabled(this.root);
    }
    ngAfterContentInit() {
        this.subscribe(this.contentChildren.changes, () => {
            this.refreshColumns();
        });
        this.refreshColumns();
    }
    refreshColumns() {
        const columns = CommonsTable2Columns.listColumns(this.contentChildren);
        let widths = CommonsTable2Columns.getGridTemplateColumns(columns);
        if (this.selectable)
            widths = `52px ${widths}`;
        setTimeout(() => { this.hostGridTemplateColumns = widths; }, 0);
    }
    doSelectAll() {
        this.selectAllChange.emit(this.selectAll);
    }
};
CommonsTable2HeaderColumnsComponent.ctorParameters = () => [
    { type: CommonsTable2Component },
    { type: CommonsTable2Service }
];
__decorate([
    HostBinding('style.gridTemplateColumns')
], CommonsTable2HeaderColumnsComponent.prototype, "hostGridTemplateColumns", void 0);
__decorate([
    ContentChildren(CommonsTable2HeaderColumnComponent)
], CommonsTable2HeaderColumnsComponent.prototype, "contentChildren", void 0);
__decorate([
    Input()
], CommonsTable2HeaderColumnsComponent.prototype, "selectAll", void 0);
__decorate([
    Output()
], CommonsTable2HeaderColumnsComponent.prototype, "selectAllChange", void 0);
CommonsTable2HeaderColumnsComponent = __decorate([
    Component({
        selector: '[commons-table2-header-columns]',
        template: "<td *ngIf=\"this.selectable !== undefined\">\n\t<commons-checkbox *ngIf=\"this.selectable === ECommonsTable2Selectable.MULTIPLE\"\n\t\t\t[disabled]=\"this.disabled\"\n\t\t\t[(checked)]=\"this.selectAll\"\n\t\t\t(checkedChange)=\"this.doSelectAll();\"\n\t></commons-checkbox>\n</td>\n<ng-content></ng-content>\n",
        styles: [":host{display:grid;box-sizing:content-box;padding:6px 0;grid-auto-columns:auto;grid-template-rows:44px;align-items:center}td{display:block;box-sizing:border-box;padding:0 16px}td commons-checkbox{position:relative;top:2px}"]
    })
], CommonsTable2HeaderColumnsComponent);

let CommonsTable2HeaderFilterComponent = class CommonsTable2HeaderFilterComponent extends CommonsComponent {
};
CommonsTable2HeaderFilterComponent = __decorate([
    Component({
        selector: '[commons-table2-header-filter]',
        template: "<ng-content></ng-content>\n",
        styles: [":host{display:block}"]
    })
], CommonsTable2HeaderFilterComponent);

var NgxWebAppCommonsTableModule_1;
let NgxWebAppCommonsTableModule = NgxWebAppCommonsTableModule_1 = class NgxWebAppCommonsTableModule {
    static forRoot() {
        return {
            ngModule: NgxWebAppCommonsTableModule_1,
            providers: [
                CommonsTable2Service
            ]
        };
    }
};
NgxWebAppCommonsTableModule = NgxWebAppCommonsTableModule_1 = __decorate([
    NgModule({
        imports: [
            CommonModule,
            NgxAngularCommonsCoreModule,
            NgxAngularCommonsBrowserModule,
            NgxAngularCommonsPipeModule,
            NgxWebAppCommonsCoreModule,
            NgxWebAppCommonsFormModule
        ],
        declarations: [
            CommonsTable2Component,
            CommonsTable2HeaderComponent,
            CommonsTable2HeaderFilterComponent,
            CommonsTable2HeaderColumnsComponent,
            CommonsTable2HeaderColumnComponent,
            CommonsTable2BodyComponent,
            CommonsTable2BodyRowComponent,
            CommonsTable2BodyCellComponent,
            CommonsTable2FooterComponent,
            CommonsTable2FooterPaginationComponent
        ],
        exports: [
            CommonsTable2Component,
            CommonsTable2HeaderComponent,
            CommonsTable2HeaderFilterComponent,
            CommonsTable2HeaderColumnsComponent,
            CommonsTable2HeaderColumnComponent,
            CommonsTable2BodyComponent,
            CommonsTable2BodyRowComponent,
            CommonsTable2BodyCellComponent,
            CommonsTable2FooterComponent,
            CommonsTable2FooterPaginationComponent
        ]
    })
], NgxWebAppCommonsTableModule);

/*
 * Public API Surface of ngx-webappcommons-table
 */

/**
 * Generated bundle index. Do not edit.
 */

export { CommonsTable2BodyCellComponent, CommonsTable2BodyComponent, CommonsTable2BodyRowComponent, CommonsTable2Component, CommonsTable2FooterComponent, CommonsTable2FooterPaginationComponent, CommonsTable2HeaderColumnComponent, CommonsTable2HeaderColumnsComponent, CommonsTable2HeaderComponent, CommonsTable2HeaderFilterComponent, CommonsTable2Service, ECOMMONS_TABLE2_SELECTABLES, ECommonsTable2Selectable, NgxWebAppCommonsTableModule, fromECommonsTable2Selectable, isECommonsTable2Selectable, keyToECommonsTable2Selectable, toECommonsTable2Selectable, ɵ0 };
//# sourceMappingURL=ngx-webappcommons-table.js.map
